Injector API reference
======================

.. note::

    Unless specified otherwise, instance methods are **not** thread safe.

    The following functions are thread safe:

    * :meth:`Injector.get`
    * injection provided by :func:`inject` decorator (please note, however, that it doesn't say anything about decorated function thread safety)


.. automodule:: injector
    :members:
    :undoc-members:
    :show-inheritance:
